@@ -9,7 +9,19 @@ Provisional library.  Must be imported as `aioitertools.asyncio`.
 
 import asyncio
 import time
-from typing import Any, Awaitable, cast, Dict, Iterable, List, Optional, Set, Tuple
+from typing import (
+    Any,
+    AsyncGenerator,
+    AsyncIterable,
+    Awaitable,
+    cast,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Set,
+    Tuple,
+)
 
 from .builtins import iter as aiter, maybe_await
 from .helpers import deprecated_wait_param
@@ -21,7 +33,7 @@ async def as_completed(
     aws: Iterable[Awaitable[T]],
     *,
     loop: Optional[asyncio.AbstractEventLoop] = None,
-    timeout: Optional[float] = None
+    timeout: Optional[float] = None,
 ) -> AsyncIterator[T]:
     """
     Run awaitables in `aws` concurrently, and yield results as they complete.
@@ -78,12 +90,93 @@ async def as_completed(
             yield await item
 
 
+async def as_generated(
+    iterables: Iterable[AsyncIterable[T]],
+    *,
+    return_exceptions: bool = False,
+) -> AsyncIterable[T]:
+    """
+    Yield results from one or more async iterables, in the order they are produced.
+
+    Like :func:`as_completed`, but for async iterators or generators instead of futures.
+    Creates a separate task to drain each iterable, and a single queue for results.
+
+    If ``return_exceptions`` is ``False``, then any exception will be raised, and
+    pending iterables and tasks will be cancelled, and async generators will be closed.
+    If ``return_exceptions`` is ``True``, any exceptions will be yielded as results,
+    and execution will continue until all iterables have been fully consumed.
+
+    Example::
+
+        async def generator(x):
+            for i in range(x):
+                yield i
+
+        gen1 = generator(10)
+        gen2 = generator(12)
+
+        async for value in as_generated([gen1, gen2]):
+            ...  # intermixed values yielded from gen1 and gen2
+    """
+
+    exc_queue: asyncio.Queue[Exception] = asyncio.Queue()
+    queue: asyncio.Queue[T] = asyncio.Queue()
+
+    async def tailer(iter: AsyncIterable[T]) -> None:
+        try:
+            async for item in iter:
+                await queue.put(item)
+        except asyncio.CancelledError:
+            if isinstance(iter, AsyncGenerator):  # pragma:nocover
+                await iter.aclose()
+            raise
+        except Exception as e:
+            await exc_queue.put(e)
+
+    tasks = [asyncio.ensure_future(tailer(iter)) for iter in iterables]
+    pending = set(tasks)
+
+    try:
+        while pending:
+            try:
+                exc = exc_queue.get_nowait()
+                if return_exceptions:
+                    yield exc  # type: ignore
+                else:
+                    raise exc
+            except asyncio.QueueEmpty:
+                pass
+
+            try:
+                value = queue.get_nowait()
+                yield value
+            except asyncio.QueueEmpty:
+                for task in list(pending):
+                    if task.done():
+                        pending.remove(task)
+                await asyncio.sleep(0.001)
+
+    except (asyncio.CancelledError, GeneratorExit):
+        pass
+
+    finally:
+        for task in tasks:
+            if not task.done():
+                task.cancel()
+
+        for task in tasks:
+            try:
+                await task
+            except asyncio.CancelledError:
+                pass
+
+
 @deprecated_wait_param
 async def gather(
     *args: Awaitable[T],
     loop: Optional[asyncio.AbstractEventLoop] = None,
     return_exceptions: bool = False,
-    limit: int = -1
+    limit: int = -1,
 ) -> List[Any]:
     """
     Like asyncio.gather but with a limit on concurrency.
