@@ -1,6 +1,8 @@
 # Copyright 2018 John Reese
 # Licensed under the MIT license
 
+import sys
+
 from typing import (
     AsyncIterable,
     AsyncIterator,
@@ -12,6 +14,13 @@ from typing import (
     Union,
 )
 
+if sys.version_info < (3, 10):  # pragma: no cover
+    from typing_extensions import ParamSpec
+else:  # pragma: no cover
+    from typing import ParamSpec
+
+
+P = ParamSpec("P")
 R = TypeVar("R")
 T = TypeVar("T")
 T1 = TypeVar("T1")
